@@ -196,13 +196,15 @@ gck_modules_get_slots (GList *modules, gboolean token_present)
 /**
  * gck_modules_enumerate_objects:
  * @modules: (element-type Gck.Module): The modules
- * @attrs: Attributes that the objects must have, or empty for all objects
+ * @attrs: attributes that the objects must have, or empty for all objects
  * @session_options: Options from GckSessionOptions
  *
  * Setup an enumerator for listing matching objects on the modules.
  *
  * This call will not block but will return an enumerator immediately.
-
+ *
+ * If the @attrs #GckAttributes is floating, it is consumed.
+ *
  * Return value: (transfer full): A new enumerator, which should be released
  * with g_object_unref().
  **/
@@ -216,7 +218,7 @@ gck_modules_enumerate_objects (GList *modules,
 	g_return_val_if_fail (attrs, NULL);
 
 	uri_data = gck_uri_data_new ();
-	uri_data->attributes = gck_attributes_ref (attrs);
+	uri_data->attributes = gck_attributes_ref_sink (attrs);
 
 	return _gck_enumerator_new_for_modules (modules, session_options, uri_data);
 }
