@@ -25,6 +25,8 @@
 
 #include "gcr-prompt.h"
 
+#include <glib/gi18n-lib.h>
+
 /**
  * SECTION:gcr-prompt
  * @title: GcrPrompt
@@ -68,7 +70,7 @@
 
 /**
  * GcrPromptReply:
- * @GCR_PROMPT_REPLY_OK: the user replied with 'ok'
+ * @GCR_PROMPT_REPLY_CONTINUE: the user replied with 'ok'
  * @GCR_PROMPT_REPLY_CANCEL: the prompt was cancelled
  *
  * Various replies returned by gcr_prompt_confirm() and friends.
@@ -102,7 +104,7 @@ gcr_prompt_default_init (GcrPromptIface *iface)
 		 */
 		g_object_interface_install_property (iface,
 		                g_param_spec_string ("title", "Title", "Prompt title",
-		                                     NULL, G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
+		                                     NULL, G_PARAM_READWRITE | G_PARAM_CONSTRUCT | G_PARAM_STATIC_STRINGS));
 
 		/**
 		 * GcrPrompt:message:
@@ -113,7 +115,7 @@ gcr_prompt_default_init (GcrPromptIface *iface)
 		 */
 		g_object_interface_install_property (iface,
 		                g_param_spec_string ("message", "Message", "Prompt message",
-		                                     NULL, G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
+		                                     NULL, G_PARAM_READWRITE | G_PARAM_CONSTRUCT | G_PARAM_STATIC_STRINGS));
 
 		/**
 		 * GcrPrompt:description:
@@ -125,7 +127,7 @@ gcr_prompt_default_init (GcrPromptIface *iface)
 		 */
 		g_object_interface_install_property (iface,
 		                g_param_spec_string ("description", "Description", "Prompt description",
-		                                     NULL, G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
+		                                     NULL, G_PARAM_READWRITE | G_PARAM_CONSTRUCT | G_PARAM_STATIC_STRINGS));
 
 		/**
 		 * GcrPrompt:warning:
@@ -137,7 +139,7 @@ gcr_prompt_default_init (GcrPromptIface *iface)
 		 */
 		g_object_interface_install_property (iface,
 		                g_param_spec_string ("warning", "Warning", "Prompt warning",
-		                                     NULL, G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
+		                                     NULL, G_PARAM_READWRITE | G_PARAM_CONSTRUCT | G_PARAM_STATIC_STRINGS));
 
 		/**
 		 * GcrPrompt:password-new:
@@ -180,7 +182,7 @@ gcr_prompt_default_init (GcrPromptIface *iface)
 		 */
 		g_object_interface_install_property (iface,
 		                g_param_spec_string ("choice-label", "Choice label", "Label for prompt choice",
-		                                     NULL, G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
+		                                     NULL, G_PARAM_READWRITE | G_PARAM_CONSTRUCT | G_PARAM_STATIC_STRINGS));
 
 		/**
 		 * GcrPrompt:choice-chosen:
@@ -204,7 +206,25 @@ gcr_prompt_default_init (GcrPromptIface *iface)
 		 */
 		g_object_interface_install_property (iface,
 		                g_param_spec_string ("caller-window", "Caller window", "Window ID of application window requesting prompt",
-		                                     NULL, G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
+		                                     NULL, G_PARAM_READWRITE | G_PARAM_CONSTRUCT | G_PARAM_STATIC_STRINGS));
+
+		/**
+		 * GcrPrompt:continue-label:
+		 *
+		 * The label for the continue button in the prompt.
+		 */
+		g_object_interface_install_property (iface,
+		                g_param_spec_string ("continue-label", "Continue label", "Continue button label",
+		                                     _("Continue"), G_PARAM_READWRITE | G_PARAM_CONSTRUCT | G_PARAM_STATIC_STRINGS));
+
+		/**
+		 * GcrPrompt:cancel-label:
+		 *
+		 * The label for the cancel button in the prompt.
+		 */
+		g_object_interface_install_property (iface,
+		                g_param_spec_string ("cancel-label", "Cancel label", "Cancel button label",
+		                                     _("Cancel"), G_PARAM_READWRITE | G_PARAM_CONSTRUCT | G_PARAM_STATIC_STRINGS));
 
 		g_once_init_leave (&initialized, 1);
 	}
@@ -249,6 +269,48 @@ on_run_complete (GObject *source,
 	g_main_loop_quit (closure->loop);
 }
 
+void
+gcr_prompt_reset (GcrPrompt *prompt)
+{
+	GParamSpec **params;
+	GcrPromptIface *iface;
+	guint i, n_params;
+
+	g_return_if_fail (GCR_IS_PROMPT (prompt));
+
+	iface = GCR_PROMPT_GET_INTERFACE (prompt);
+	params = g_object_interface_list_properties (iface, &n_params);
+
+	g_object_freeze_notify (G_OBJECT (prompt));
+
+	for (i = 0; i < n_params; i++) {
+		if (!(params[i]->flags & G_PARAM_WRITABLE))
+			continue;
+
+		if (params[i]->value_type == G_TYPE_STRING)
+			g_object_set (prompt, params[i]->name,
+			              ((GParamSpecString *)params[i])->default_value,
+			              NULL);
+
+		else if (params[i]->value_type == G_TYPE_INT)
+			g_object_set (prompt, params[i]->name,
+			              ((GParamSpecInt *)params[i])->default_value,
+			              NULL);
+
+		else if (params[i]->value_type == G_TYPE_BOOLEAN)
+			g_object_set (prompt, params[i]->name,
+			              ((GParamSpecBoolean *)params[i])->default_value,
+			              NULL);
+
+		else
+			g_assert_not_reached ();
+	}
+
+	g_free (params);
+
+	g_object_thaw_notify (G_OBJECT (prompt));
+}
+
 /**
  * gcr_prompt_get_title:
  * @prompt: the prompt
@@ -265,6 +327,7 @@ gchar *
 gcr_prompt_get_title (GcrPrompt *prompt)
 {
 	gchar *title = NULL;
+	g_return_val_if_fail (GCR_IS_PROMPT (prompt), NULL);
 	g_object_get (prompt, "title", &title, NULL);
 	return title;
 }
@@ -302,6 +365,7 @@ gchar *
 gcr_prompt_get_message (GcrPrompt *prompt)
 {
 	gchar *message = NULL;
+	g_return_val_if_fail (GCR_IS_PROMPT (prompt), NULL);
 	g_object_get (prompt, "message", &message, NULL);
 	return message;
 }
@@ -339,6 +403,7 @@ gchar *
 gcr_prompt_get_description (GcrPrompt *prompt)
 {
 	gchar *description = NULL;
+	g_return_val_if_fail (GCR_IS_PROMPT (prompt), NULL);
 	g_object_get (prompt, "description", &description, NULL);
 	return description;
 }
@@ -380,6 +445,7 @@ gchar *
 gcr_prompt_get_warning (GcrPrompt *prompt)
 {
 	gchar *warning = NULL;
+	g_return_val_if_fail (GCR_IS_PROMPT (prompt), NULL);
 	g_object_get (prompt, "warning", &warning, NULL);
 	return warning;
 }
@@ -419,6 +485,7 @@ gchar *
 gcr_prompt_get_choice_label (GcrPrompt *prompt)
 {
 	gchar *choice_label = NULL;
+	g_return_val_if_fail (GCR_IS_PROMPT (prompt), NULL);
 	g_object_get (prompt, "choice-label", &choice_label, NULL);
 	return choice_label;
 }
@@ -461,6 +528,7 @@ gboolean
 gcr_prompt_get_choice_chosen (GcrPrompt *prompt)
 {
 	gboolean choice_chosen;
+	g_return_val_if_fail (GCR_IS_PROMPT (prompt), FALSE);
 	g_object_get (prompt, "choice-chosen", &choice_chosen, NULL);
 	return choice_chosen;
 }
@@ -498,6 +566,7 @@ gboolean
 gcr_prompt_get_password_new (GcrPrompt *prompt)
 {
 	gboolean password_new;
+	g_return_val_if_fail (GCR_IS_PROMPT (prompt), FALSE);
 	g_object_get (prompt, "password-new", &password_new, NULL);
 	return password_new;
 }
@@ -538,6 +607,7 @@ gint
 gcr_prompt_get_password_strength (GcrPrompt *prompt)
 {
 	gboolean password_strength;
+	g_return_val_if_fail (GCR_IS_PROMPT (prompt), 0);
 	g_object_get (prompt, "password-strength", &password_strength, NULL);
 	return password_strength;
 }
@@ -559,6 +629,7 @@ gchar *
 gcr_prompt_get_caller_window (GcrPrompt *prompt)
 {
 	gchar *caller_window = NULL;
+	g_return_val_if_fail (GCR_IS_PROMPT (prompt), NULL);
 	g_object_get (prompt, "caller-window", &caller_window, NULL);
 	return caller_window;
 }
@@ -582,6 +653,81 @@ gcr_prompt_set_caller_window (GcrPrompt *prompt,
 	g_object_set (prompt, "caller-window", window_id, NULL);
 }
 
+/**
+ * gcr_prompt_get_continue_label:
+ * @prompt: the prompt
+ *
+ * Get the label for the continue button.
+ *
+ * This is the button that results in a %GCR_PROMPT_REPLY_CONTINUE reply
+ * from the prompt.
+ *
+ * Returns: (transfer full): a newly allocated string containing the label
+ */
+gchar *
+gcr_prompt_get_continue_label (GcrPrompt *prompt)
+{
+	gchar *continue_label = NULL;
+	g_return_val_if_fail (GCR_IS_PROMPT (prompt), NULL);
+	g_object_get (prompt, "continue-label", &continue_label, NULL);
+	return continue_label;
+}
+
+/**
+ * gcr_prompt_set_continue_label:
+ * @prompt: the prompt
+ * @continue_label: the label
+ *
+ * Set the label for the continue button.
+ *
+ * This is the button that results in a %GCR_PROMPT_REPLY_CONTINUE reply
+ * from the prompt.
+ */
+void
+gcr_prompt_set_continue_label (GcrPrompt *prompt,
+                               const gchar *continue_label)
+{
+	g_return_if_fail (GCR_IS_PROMPT (prompt));
+	g_object_set (prompt, "continue-label", continue_label, NULL);
+}
+
+/**
+ * gcr_prompt_get_cancel_label:
+ * @prompt: the prompt
+ *
+ * Get the label for the cancel button.
+ *
+ * This is the button that results in a %GCR_PROMPT_REPLY_CANCEL reply
+ * from the prompt.
+ *
+ * Returns: (transfer full): a newly allocated string containing the label
+ */
+gchar *
+gcr_prompt_get_cancel_label (GcrPrompt *prompt)
+{
+	gchar *cancel_label = NULL;
+	g_object_get (prompt, "cancel-label", &cancel_label, NULL);
+	return cancel_label;
+}
+
+/**
+ * gcr_prompt_set_cancel_label:
+ * @prompt: the prompt
+ * @cancel_label: the label
+ *
+ * Set the label for the continue button.
+ *
+ * This is the button that results in a %GCR_PROMPT_REPLY_CANCEL reply
+ * from the prompt.
+ */
+void
+gcr_prompt_set_cancel_label (GcrPrompt *prompt,
+                             const gchar *cancel_label)
+{
+	g_return_if_fail (GCR_IS_PROMPT (prompt));
+	g_object_set (prompt, "cancel-label", cancel_label, NULL);
+}
+
 /**
  * gcr_prompt_password_async:
  * @prompt: a prompt
